@@ -26,6 +26,9 @@
 #include "eng1_mm.h"
 #include "tab_mm_tripos52.h"
 
+#include "local_i18n.h"
+#include "notice.h"
+
 #include <algorithm>
 #include <sstream>
 using namespace std;
@@ -56,7 +59,7 @@ eng1_mm_tripos52_bt::eng1_mm_tripos52_bt(setup * p1, i32u p2) :
 
 	// create bt1-terms...
 	
-	if (ostr != NULL) (* ostr) << "creating bt1-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating bt1-terms: ");
 	i32s bt1_err = 0;
 	
 	for (iter_bl it1 = mdl->GetBondsBegin();it1 != mdl->GetBondsEnd();it1++)
@@ -93,8 +96,8 @@ eng1_mm_tripos52_bt::eng1_mm_tripos52_bt(setup * p1, i32u p2) :
 	
 	if (ostr != NULL)
 	{
-		(* ostr) << bt1_vector.size() << " terms, ";
-		(* ostr) << bt1_err << " errors." << endl;
+		(* ostr) << bt1_vector.size() << _(" terms, ");
+		(* ostr) << bt1_err << _(" errors.") << endl;
 	}
 	
 	bt1data = new mm_bt1_data[bt1_vector.size()];
@@ -104,7 +107,7 @@ eng1_mm_tripos52_bt::eng1_mm_tripos52_bt(setup * p1, i32u p2) :
 	
 	// create bt2-terms...
 	
-	if (ostr != NULL) (* ostr) << "creating bt2-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating bt2-terms: ");
 	i32s bt2_err = 0;
 	
 	for (iter_al it1 = mdl->GetAtomsBegin();it1 != mdl->GetAtomsEnd();it1++)
@@ -152,8 +155,8 @@ eng1_mm_tripos52_bt::eng1_mm_tripos52_bt(setup * p1, i32u p2) :
 	
 	if (ostr != NULL)
 	{
-		(* ostr) << bt2_vector.size() << " terms, ";
-		(* ostr) << bt2_err << " errors." << endl;
+		(* ostr) << bt2_vector.size() << _(" terms, ");
+		(* ostr) << bt2_err << _(" errors.") << endl;
 	}
 	
 	bt2data = new mm_bt2_data[bt2_vector.size()];
@@ -163,7 +166,7 @@ eng1_mm_tripos52_bt::eng1_mm_tripos52_bt(setup * p1, i32u p2) :
 	
 	// create bt3-terms...
 
-	if (ostr != NULL) (* ostr) << "creating bt3-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating bt3-terms: ");
 	i32s bt3_err = 0;
 	
 	for (iter_al it1 = mdl->GetAtomsBegin();it1 != mdl->GetAtomsEnd();it1++)
@@ -297,8 +300,8 @@ eng1_mm_tripos52_bt::eng1_mm_tripos52_bt(setup * p1, i32u p2) :
 	
 	if (ostr != NULL)
 	{
-		(* ostr) << bt3_vector.size() << " terms, ";
-		(* ostr) << bt3_err << " errors." << endl;
+		(* ostr) << bt3_vector.size() << _(" terms, ");
+		(* ostr) << bt3_err << _(" errors.") << endl;
 	}
 	
 /*##############################################*/
@@ -310,7 +313,7 @@ eng1_mm_tripos52_bt::eng1_mm_tripos52_bt(setup * p1, i32u p2) :
 	if (total_err && GetSetup()->GetModel()->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : there were " << total_err << " missing parameters in the bonded terms." << endl << ends;
+		str << _("WARNING : there were ") << total_err << _(" missing parameters in the bonded terms.") << endl << ends;
 		mdl->PrintToLog(str.str().c_str());
 	}
 }
@@ -338,11 +341,7 @@ i32s eng1_mm_tripos52_bt::FindTorsion(atom * a1, atom * a2, atom * a3, atom * a4
 			else index++;
 		}
 		
-		if (index >= GetSetup()->GetMMAtomCount())
-		{
-			cout << "ERROR : iloc search failed!!!" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (index >= GetSetup()->GetMMAtomCount()) assertion_failed(__FILE__, __LINE__, "iloc search failed");
 		
 		iloc[n1] = index;
 	}
@@ -846,12 +845,12 @@ eng1_mm_tripos52_nbt_bp::eng1_mm_tripos52_nbt_bp(setup * p1, i32u p2) :
 	
 	if (ostr != NULL && use_bp)
 	{
-		(* ostr) << "use_bp ; ";
+		(* ostr) << _("use_bp ; ");
 		(* ostr) << bp_rad_solute << " " << bp_fc_solute << " ; ";
 		(* ostr) << bp_rad_solvent << " " << bp_fc_solvent << endl;
 	}
 	
-	if (ostr != NULL) (* ostr) << "creating nbt1-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating nbt1-terms: ");
 	i32s nbt1_err = 0;
 	
 	for (i32s ind1 = 0;ind1 < GetSetup()->GetMMAtomCount() - 1;ind1++)
@@ -921,7 +920,7 @@ eng1_mm_tripos52_nbt_bp::eng1_mm_tripos52_nbt_bp(setup * p1, i32u p2) :
 	if (total_err && GetSetup()->GetModel()->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : there were " << total_err << " missing parameters in the nonbonded terms." << endl << ends;
+		str << _("WARNING : there were ") << total_err << _(" missing parameters in the nonbonded terms.") << endl << ends;
 		mdl->PrintToLog(str.str().c_str());
 	}
 }
@@ -1133,8 +1132,7 @@ eng1_mm_tripos52_nbt_mim::eng1_mm_tripos52_nbt_mim(setup * p1, i32u p2) :
 	
 	if (nskip > 0)
 	{
-		static const char msg[] = "Cannot skip the nonbonded terms\nas requested in distance constraints.";
-		GetSetup()->GetModel()->WarningMessage(msg);
+		GetSetup()->GetModel()->WarningMessage(_("Cannot skip the nonbonded terms\nas requested in distance constraints."));
 	}
 }
 
@@ -1294,7 +1292,7 @@ void eng1_mm_tripos52_nbt_mim::UpdateTerms(void)
 	
 	nbt1_vector.resize(0);
 	
-	if (ostr != NULL) (* ostr) << "creating nbt1-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating nbt1-terms: ");
 	i32s nbt1_err = 0;
 	
 	for (i32s ind1 = 0;ind1 < GetSetup()->GetMMAtomCount() - 1;ind1++)
@@ -1365,7 +1363,7 @@ void eng1_mm_tripos52_nbt_mim::UpdateTerms(void)
 	if (total_err && GetSetup()->GetModel()->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : there were " << total_err << " missing parameters in the nonbonded terms." << endl << ends;
+		str << _("WARNING : there were ") << total_err << _(" missing parameters in the nonbonded terms.") << endl << ends;
 		mdl->PrintToLog(str.str().c_str());
 	}
 }
