@@ -22,10 +22,13 @@
 #include "engine.h"
 
 #include "v3d.h"
-
 #include "model.h"
 
+#include "local_i18n.h"
+#include "notice.h"
+
 #include <vector>
+#include <sstream>
 using namespace std;
 
 /*################################################################################################*/
@@ -179,8 +182,9 @@ void setup::UpdateSetupInfo(void)
 	
 	if (qm_nbnd + mm_nbnd + boundary_nbnd != nbnd)
 	{
-		cout << "ERROR : bond counting mismatch : " << qm_nbnd << " + " << mm_nbnd << " + " << boundary_nbnd << " != " << nbnd << endl;
-		exit(EXIT_FAILURE);
+		ostringstream msg;
+		msg << "bond counting mismatch : " << qm_nbnd << " + " << mm_nbnd << " + " << boundary_nbnd << " != " << nbnd << ends;
+		assertion_failed(__FILE__, __LINE__, msg.str().c_str());
 	}
 	
 	// allocate the tables.
@@ -280,17 +284,55 @@ void setup::UpdateSetupInfo(void)
 	// finally check that the counts match!!!
 	// finally check that the counts match!!!
 	
-	if ((i32s) ac != natm) { cout << "ERROR : atom mismatch! " << ac << " != " << natm << endl; exit(EXIT_FAILURE); }
+	if ((i32s) ac != natm)
+	{
+		ostringstream msg;
+		msg << "atom mismatch : " << ac << " != " << natm << ends;
+		assertion_failed(__FILE__, __LINE__, msg.str().c_str());
+	}
 	
-	if ((i32s) qm_ac != qm_natm) { cout << "ERROR : qm-atom mismatch! " << qm_ac << " != " << qm_natm << endl; exit(EXIT_FAILURE); }
-	if ((i32s) qm_bc != qm_nbnd) { cout << "ERROR : qm-bond mismatch! " << qm_bc << " != " << qm_nbnd << endl; exit(EXIT_FAILURE); }
+	if ((i32s) qm_ac != qm_natm)
+	{
+		ostringstream msg;
+		msg << "qm-atom mismatch : " << qm_ac << " != " << qm_natm << ends;
+		assertion_failed(__FILE__, __LINE__, msg.str().c_str());
+	}
 	
-	if ((i32s) mm_ac != mm_natm) { cout << "ERROR : mm-atom mismatch! " << mm_ac << " != " << mm_natm << endl; exit(EXIT_FAILURE); }
-	if ((i32s) mm_bc != mm_nbnd) { cout << "ERROR : mm-bond mismatch! " << mm_bc << " != " << mm_nbnd << endl; exit(EXIT_FAILURE); }
+	if ((i32s) qm_bc != qm_nbnd)
+	{
+		ostringstream msg;
+		msg << "qm-bond mismatch : " << qm_bc << " != " << qm_nbnd << ends;
+		assertion_failed(__FILE__, __LINE__, msg.str().c_str());
+	}
 	
-	if ((i32s) boundary_bc != boundary_nbnd) { cout << "ERROR : boundary-bond mismatch! " << boundary_bc << " != " << boundary_nbnd << endl; exit(EXIT_FAILURE); }
+	if ((i32s) mm_ac != mm_natm)
+	{
+		ostringstream msg;
+		msg << "mm-atom mismatch : " << mm_ac << " != " << mm_natm << ends;
+		assertion_failed(__FILE__, __LINE__, msg.str().c_str());
+	}
+	
+	if ((i32s) mm_bc != mm_nbnd)
+	{
+		ostringstream msg;
+		msg << "mm-bond mismatch : " << mm_bc << " != " << mm_nbnd << ends;
+		assertion_failed(__FILE__, __LINE__, msg.str().c_str());
+	}
+	
+	if ((i32s) boundary_bc != boundary_nbnd)
+	{
+		ostringstream msg;
+		msg << "boundary-bond mismatch : " << boundary_bc << " != " << boundary_nbnd << ends;
+		assertion_failed(__FILE__, __LINE__, msg.str().c_str());
+	}
+	
+	if ((i32s) sf_ac != sf_natm)
+	{
+		ostringstream msg;
+		msg << "sf-atom mismatch : " << sf_ac << " != " << sf_natm << ends;
+		assertion_failed(__FILE__, __LINE__, msg.str().c_str());
+	}
 	
-	if ((i32s) sf_ac != sf_natm) { cout << "ERROR : sf-atom mismatch! " << sf_ac << " != " << sf_natm << endl; exit(EXIT_FAILURE); }
 //////////////////////////////////////////////////
 //////////////////////////////////////////////////
 //cout << "atoms : " << qm_ac << " " << mm_ac << " " << sf_ac << "     bonds : " << qm_bc << " " << mm_bc << endl;	//CGI!
@@ -330,7 +372,7 @@ engine * setup::CreateEngineByIDNumber(i32u id)
 	}
 	else
 	{
-		cout << "setup::CreateEngineByIDNumber() failed!" << endl;
+		cout << "WARNING : setup::CreateEngineByIDNumber() failed!" << endl;
 		return NULL;
 	}
 }
@@ -340,7 +382,7 @@ engine * setup::CreateEngineByIDNumber(i32u id)
 engine::engine(setup * p1, i32u p2)
 {
 	stp = p1;
-	if (!stp->HasSetupTables()) { cout << "fatal error : no setup tables at engine::engine()." << endl; exit(EXIT_FAILURE); }
+	if (!stp->HasSetupTables()) assertion_failed(__FILE__, __LINE__, "no setup tables");
 	
 	// here it is very important that we take the atom count from setup::GetAtomCount(), not model::GetAtomCount()!!!
 	// it is possible that these are not at all the same!!! some atoms might be hidden from the calculations.
@@ -484,11 +526,7 @@ void engine::ecomp_AddStore2(int gA, int gB, int sc, double value)
 	
 	const int index = (gHI * (gHI + 1) / 2) + gLO;
 	
-	if (index >= ECOMPstore_size)
-	{
-		cout << "callEXIT : index overflow at engine::ecomp_AddStore()." << endl;
-		exit(EXIT_FAILURE);
-	}
+	if (index >= ECOMPstore_size) assertion_failed(__FILE__, __LINE__, "index overflow");
 	
 	ECOMPstore[index][sc] += value;
 }
@@ -568,11 +606,7 @@ double engine::ecomp_ReadStore(int gA, int gB, int sc)
 	
 	const int index = (gHI * (gHI + 1) / 2) + gLO;
 	
-	if (index >= ECOMPstore_size)
-	{
-		cout << "callEXIT : index overflow at engine::ecomp_AddStore()." << endl;
-		exit(EXIT_FAILURE);
-	}
+	if (index >= ECOMPstore_size) assertion_failed(__FILE__, __LINE__, "index overflow");
 	
 	return (ECOMPstore[index][sc] / (double) ECOMPcycles);
 }
@@ -611,11 +645,7 @@ fGL value_OrbDens(engine * eng, fGL * crd, fGL * grad)
 
 void CopyCRD(model * p1, engine * p2, i32u p3)
 {
-	if (p3 >= p1->cs_vector.size())
-	{
-		cout << "BUG: cs overflow at CopyCRD() mdl->eng." << endl;
-		exit(EXIT_FAILURE);
-	}
+	if (p3 >= p1->cs_vector.size()) assertion_failed(__FILE__, __LINE__, "cs overflow");
 	
 	atom ** glob_atmtab = p2->GetSetup()->GetAtoms();
 	for (i32s n1 = 0;n1 < p2->GetSetup()->GetAtomCount();n1++)
@@ -652,11 +682,7 @@ void CopyCRD(model * p1, engine * p2, i32u p3)
 				v3d<fGL> v3(ref_to_O->GetCRD(p3), ref_to_C->GetCRD(p3));
 				fGL pbdd = v1.tor(v2, v3);
 				
-				if (bt3_counter >= (i32s) esf->bt3_vector.size())
-				{
-					cout << "oops! something went wrong when trying to update bt3::pbdd" << endl;
-					exit(EXIT_FAILURE);
-				}
+				if (bt3_counter >= (i32s) esf->bt3_vector.size()) assertion_failed(__FILE__, __LINE__, "bt3_counter overflow");
 				
 				esf->bt3_vector[bt3_counter++].pbdd = pbdd;
 			}
@@ -670,11 +696,7 @@ void CopyCRD(model * p1, engine * p2, i32u p3)
 
 void CopyCRD(engine * p1, model * p2, i32u p3)
 {
-	if (p3 >= p2->cs_vector.size())
-	{
-		cout << "BUG: cs overflow at CopyCRD() eng->mdl." << endl;
-		exit(EXIT_FAILURE);
-	}
+	if (p3 >= p2->cs_vector.size()) assertion_failed(__FILE__, __LINE__, "cs overflow");
 	
 	atom ** glob_atmtab = p1->GetSetup()->GetAtoms();
 	for (i32s n1 = 0;n1 < p1->GetSetup()->GetAtomCount();n1++)
@@ -708,11 +730,7 @@ void CopyCRD(engine * p1, model * p2, i32u p3)
 				v3d<fGL> v3 = v1.vpr(v2); v3 = v3 / v3.len();		// this is vector c in the JCC 2001 paper.
 				v3d<fGL> v4 = v2.vpr(v3); v4 = v4 / v4.len();		// this is vector n in the JCC 2001 paper.
 				
-				if (bt3_counter >= (i32s) esf->bt3_vector.size())
-				{
-					cout << "oops! something went wrong when trying to update the N/C/O atoms!" << endl;
-					exit(EXIT_FAILURE);
-				}
+				if (bt3_counter >= (i32s) esf->bt3_vector.size()) assertion_failed(__FILE__, __LINE__, "bt3_counter overflow");
 				
 				fGL pbdd = esf->bt3_vector[bt3_counter++].pbdd;
 				v3d<fGL> v5 = (v4 * cos(pbdd)) - (v3 * sin(pbdd));
@@ -776,11 +794,7 @@ engine_pbc::engine_pbc(setup * p1, i32u p2) : engine(p1, p2)
 // level is the highest criteria in sorting, atoms in a molecule should
 // be adjacent -> a continuous range of pointers.
 	
-	if (!GetSetup()->GetModel()->IsGroupsSorted())
-	{
-		cout << "engine_pbc ctor ; IsGroupsSorted() returned false!" << endl;
-		exit(EXIT_FAILURE);
-	}
+	if (!GetSetup()->GetModel()->IsGroupsSorted()) assertion_failed(__FILE__, __LINE__, "not_sorted");
 	
 // here we calculate the molecule locations precisely, but a simple trigger atom could be used as well...
 	
@@ -869,11 +883,7 @@ number_density_evaluator::number_density_evaluator(engine_bp * p1, bool p2, i32s
 	linear = p2;
 	classes = p3;
 	
-	if (!eng->use_bp)
-	{
-		cout << "number_density_evaluator : eng->use_bp was false!" << endl;
-		exit(EXIT_FAILURE);
-	}
+	if (!eng->use_bp) assertion_failed(__FILE__, __LINE__, "use_bp is false");
 	
 	upper_limits = new f64[classes];
 	class_volumes = new f64[classes];
@@ -951,7 +961,7 @@ void number_density_evaluator::PrintResults(ostream & str)
 	}
 	
 	f64 tmp1 = ((f64) counts[classes]) / ((f64) cycles);
-	str << "(outside bp_radius = " << tmp1 << ")." << endl;
+	str << _("(outside bp_radius = ") << tmp1 << ")." << endl;
 	
 	ResetCounters();
 }
@@ -971,25 +981,13 @@ radial_density_function_evaluator::radial_density_function_evaluator(engine_bp *
 	
 	if (count_begin < 0.0)
 	{
-		if (!eng->use_bp)
-		{
-			cout << "radial_density_function_evaluator : eng->use_bp was false!" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (!eng->use_bp) assertion_failed(__FILE__, __LINE__, "use_bp is false");
 		
-		if (!eng->nd_eval)
-		{
-			cout << "radial_density_function_evaluator : eng->nd_eval was NULL!" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (!eng->nd_eval) assertion_failed(__FILE__, __LINE__, "nd_eval is NULL");
 		
 		f64 graph_width = graph_end - graph_begin;
 		f64 count_width = count_end - count_begin;
-		if (count_width < graph_width)
-		{
-			cout << "radial_density_function_evaluator : too narrow counting window!" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (count_width < graph_width) assertion_failed(__FILE__, __LINE__, "bad width");
 	}
 	
 	upper_limits = new f64[classes];
