@@ -23,8 +23,10 @@
 
 #include "v3d.h"
 
-//#include <string.h>
-#include <cstring>	// required by gcc-4.3
+#include "local_i18n.h"
+#include "notice.h"
+
+#include <cstring>
 #include <iomanip>
 #include <iostream>
 #include <sstream>
@@ -78,8 +80,7 @@ int sb_chain_descriptor::AddRes3(const char * r3l)
 {
 	if (strlen(r3l) != 3)
 	{
-		cout << "callEXIT : sb_chain_descriptor::AddRes3() ; bad input" << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "bad input");
 	}
 	
 	char * tmps = new char[4];
@@ -127,7 +128,7 @@ void sb_chain_descriptor::AddTOR(int tor_ind, float tor_val)
 
 /*################################################################################################*/
 
-sequencebuilder::sequencebuilder(chn_info::chn_type ct, char * filename)
+sequencebuilder::sequencebuilder(chn_info::chn_type ct, const char * filename)
 {
 	type = ct;
 	
@@ -220,24 +221,21 @@ sequencebuilder::sequencebuilder(chn_info::chn_type ct, char * filename)
 	file.getline(buffer, sizeof(buffer)); mod[0] = new sb_data_res; mod[0]->ReadModification(file);
 	if (mod[0]->td_vector.size() > 0)
 	{
-		cout << "callEXIT : BODY_MOD should not have any TORDEF lines!" << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "BODY_MOD should not have TORDEF lines!");
 	}
 	
 	while (file.peek() != 'H') file.getline(buffer, sizeof(buffer));	// head-mods
 	file.getline(buffer, sizeof(buffer)); mod[1] = new sb_data_res; mod[1]->ReadModification(file);
 	if (mod[1]->td_vector.size() > 0)
 	{
-		cout << "callEXIT : HEAD_MOD should not have any TORDEF lines!" << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "HEAD_MOD should not have TORDEF lines!");
 	}
 	
 	while (file.peek() != 'T') file.getline(buffer, sizeof(buffer));	// tail-mods
 	file.getline(buffer, sizeof(buffer)); mod[2] = new sb_data_res; mod[2]->ReadModification(file);
 	if (mod[2]->td_vector.size() > 0)
 	{
-		cout << "callEXIT : TAIL_MOD should not have any TORDEF lines!" << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "TAIL_MOD should not have TORDEF lines!");
 	}
 	
 	// read descriptions for the residues...
@@ -281,8 +279,7 @@ void sequencebuilder::Build(model * mdl, sb_chain_descriptor * chde, bool do_cen
 	
 	if (bad_chde)
 	{
-		cout << "callEXIT : sequencebuilder::Build() ; bad input" << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "bad input");
 	}
 	
 	const int num_res = (chde->mode_1_letter ? chde->seq1->size() : chde->seq3->size());
@@ -407,8 +404,7 @@ void sequencebuilder::Build(model * mdl, sb_chain_descriptor * chde, bool do_cen
 				
 				if (index >= id_vector.size())
 				{
-					cout << "callEXIT : ERROR : amino-terminal N missing?" << endl;
-					exit(EXIT_FAILURE);
+					assertion_failed(__FILE__, __LINE__, "amino-terminal N missing?");
 				}
 				
 				atom_vector[index]->formal_charge = +1;
@@ -452,7 +448,7 @@ void sequencebuilder::Build(model * mdl, sb_chain_descriptor * chde, bool do_cen
 		else
 		{
 			ostringstream str;
-			str << "unknown residue ";
+			str << _("unknown residue ");
 			
 			if (chde->mode_1_letter)
 			{
@@ -515,14 +511,12 @@ void sequencebuilder::Identify(model * mdl)
 {
 	if (!mdl->IsGroupsClean())
 	{
-		cout << "callEXIT : is_groups_clean was false at sequencebuilder::Identify()." << endl;
-		exit(EXIT_FAILURE);	//mdl->UpdateGroups();
+		assertion_failed(__FILE__, __LINE__, "!mdl->IsGroupsClean()");
 	}
 	
 	if (mdl->ref_civ == NULL)
 	{
-		cout << "callEXIT : mdl->ref_civ == NULL at sequencebuilder::Identify()." << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "mdl->ref_civ == NULL");
 	}
 	
 	// here we will find all possible chains and identify them.
@@ -573,7 +567,7 @@ void sequencebuilder::Identify(model * mdl)
 		if (path_vector.size())
 		{
 			ostringstream str;
-			str << path_vector.size() << " chains:" << endl << ends;
+			str << path_vector.size() << _(" chains:") << endl << ends;
 			if (mdl->verbosity >= 3) mdl->PrintToLog(str.str().c_str());
 		}
 		
@@ -622,7 +616,7 @@ void sequencebuilder::Identify(model * mdl)
 					
 					if (refX != NULL)
 					{
-						cout << "found an ACE-like-block!" << endl;
+						cout << _("found an ACE-like-block!") << endl;
 						//exit(EXIT_FAILURE);
 						
 						head_el = refX->el.GetAtomicNumber();
@@ -652,7 +646,7 @@ void sequencebuilder::Identify(model * mdl)
 					
 					if (refX != NULL)
 					{
-						cout << "found an NME-like-block!" << endl;
+						cout << _("found an NME-like-block!") << endl;
 						//exit(EXIT_FAILURE);
 						
 						tail_el = refX->el.GetAtomicNumber();
@@ -683,8 +677,7 @@ void sequencebuilder::Identify(model * mdl)
 					{
 						if (is_first)
 						{
-							cout << "callEXIT : bad head_el" << endl;
-							exit(EXIT_FAILURE);
+							assertion_failed(__FILE__, __LINE__, "bad head_el");
 						}
 						
 						// ACE needs no modifications...
@@ -694,8 +687,7 @@ void sequencebuilder::Identify(model * mdl)
 					{
 						if (is_last)
 						{
-							cout << "callEXIT : bad tail_el" << endl;
-							exit(EXIT_FAILURE);
+							assertion_failed(__FILE__, __LINE__, "bad tail_el");
 						}
 						
 						for (i32s n5 = 0;n5 < (i32s) tdata.size();n5++)
@@ -740,7 +732,7 @@ void sequencebuilder::Identify(model * mdl)
 				if (tmp1[0] == NOT_DEFINED)
 				{
 					ostringstream str;
-					str << "WARNING : residue " << rcount << " was of unknown type!!!" << endl << ends;
+					str << _("WARNING : residue ") << rcount << _(" was of unknown type!!!") << endl << ends;
 					if (mdl->verbosity >= 2) mdl->PrintToLog(str.str().c_str());
 					
 					tmpseq1.push_back('?');		// handle the sequence...
@@ -818,10 +810,10 @@ if (type == chn_info::amino_acid && resi_vector[tmp1[0]].symbol1 == 'L')
 		if ((tdata[n4].ref->builder_res_id & 0xFF) == 0x23) ref23 = tdata[n4].ref;
 	}
 	
-	if (!ref20) { cout << "callEXIT : LEU-fix : ref20 not found!" << endl; exit(EXIT_FAILURE); }
-	if (!ref21) { cout << "callEXIT : LEU-fix : ref21 not found!" << endl; exit(EXIT_FAILURE); }
-	if (!ref22) { cout << "callEXIT : LEU-fix : ref22 not found!" << endl; exit(EXIT_FAILURE); }
-	if (!ref23) { cout << "callEXIT : LEU-fix : ref23 not found!" << endl; exit(EXIT_FAILURE); }
+	if (!ref20) assertion_failed(__FILE__, __LINE__, "LEU-fix : ref20 not found!");
+	if (!ref21) assertion_failed(__FILE__, __LINE__, "LEU-fix : ref21 not found!");
+	if (!ref22) assertion_failed(__FILE__, __LINE__, "LEU-fix : ref22 not found!");
+	if (!ref23) assertion_failed(__FILE__, __LINE__, "LEU-fix : ref23 not found!");
 	
 	v3d<fGL> v1 = v3d<fGL>(ref21->GetCRD(0), ref20->GetCRD(0));
 	v3d<fGL> v2 = v3d<fGL>(ref21->GetCRD(0), ref22->GetCRD(0));
@@ -830,7 +822,7 @@ if (type == chn_info::amino_acid && resi_vector[tmp1[0]].symbol1 == 'L')
 	
 	if (tor < 0.0)	// should be +/- 120 deg (about +/- 2.1 rad).
 	{
-		cout << "LEU-fix!!!" << endl;
+		cout << _("LEU-fix!!!") << endl;
 		
 		// ok, this seems to be "wrong" way...
 		// fix by exhanging 22<->23.
@@ -862,10 +854,10 @@ if (type == chn_info::amino_acid && resi_vector[tmp1[0]].symbol1 == 'V')
 		if ((tdata[n4].ref->builder_res_id & 0xFF) == 0x22) ref22 = tdata[n4].ref;
 	}
 	
-	if (!ref01) { cout << "callEXIT : VAL-fix : ref01 not found!" << endl; exit(EXIT_FAILURE); }
-	if (!ref20) { cout << "callEXIT : VAL-fix : ref20 not found!" << endl; exit(EXIT_FAILURE); }
-	if (!ref21) { cout << "callEXIT : VAL-fix : ref21 not found!" << endl; exit(EXIT_FAILURE); }
-	if (!ref22) { cout << "callEXIT : VAL-fix : ref22 not found!" << endl; exit(EXIT_FAILURE); }
+	if (!ref01) assertion_failed(__FILE__, __LINE__, "VAL-fix : ref01 not found!");
+	if (!ref20) assertion_failed(__FILE__, __LINE__, "VAL-fix : ref20 not found!");
+	if (!ref21) assertion_failed(__FILE__, __LINE__, "VAL-fix : ref21 not found!");
+	if (!ref22) assertion_failed(__FILE__, __LINE__, "VAL-fix : ref22 not found!");
 	
 	v3d<fGL> v1 = v3d<fGL>(ref20->GetCRD(0), ref01->GetCRD(0));
 	v3d<fGL> v2 = v3d<fGL>(ref20->GetCRD(0), ref21->GetCRD(0));
@@ -874,7 +866,7 @@ if (type == chn_info::amino_acid && resi_vector[tmp1[0]].symbol1 == 'V')
 	
 	if (tor < 0.0)	// should be +/- 120 deg (about +/- 2.1 rad).
 	{
-		cout << "VAL-fix!!!" << endl;
+		cout << _("VAL-fix!!!") << endl;
 		
 		// ok, this seems to be "wrong" way...
 		// fix by exhanging 21<->22.
@@ -908,11 +900,11 @@ if (type == chn_info::amino_acid && resi_vector[tmp1[0]].symbol1 == 'W')
 		if ((tdata[n4].ref->builder_res_id & 0xFF) == 0x29) ref29 = tdata[n4].ref;
 	}
 	
-	if (!ref23) { cout << "callEXIT : TRP-fix : ref23 not found!" << endl; exit(EXIT_FAILURE); }
-	if (!ref25) { cout << "callEXIT : TRP-fix : ref25 not found!" << endl; exit(EXIT_FAILURE); }
-	if (!ref26) { cout << "callEXIT : TRP-fix : ref26 not found!" << endl; exit(EXIT_FAILURE); }
-	if (!ref28) { cout << "callEXIT : TRP-fix : ref28 not found!" << endl; exit(EXIT_FAILURE); }
-	if (!ref29) { cout << "callEXIT : TRP-fix : ref29 not found!" << endl; exit(EXIT_FAILURE); }
+	if (!ref23) assertion_failed(__FILE__, __LINE__, "TRP-fix : ref23 not found!");
+	if (!ref25) assertion_failed(__FILE__, __LINE__, "TRP-fix : ref25 not found!");
+	if (!ref26) assertion_failed(__FILE__, __LINE__, "TRP-fix : ref26 not found!");
+	if (!ref28) assertion_failed(__FILE__, __LINE__, "TRP-fix : ref28 not found!");
+	if (!ref29) assertion_failed(__FILE__, __LINE__, "TRP-fix : ref29 not found!");
 	
 	bond b1 = bond(ref23, ref25, bondtype('S'));
 	iter_bl itb1 = find(mdl->GetBondsBegin(), mdl->GetBondsEnd(), b1);
@@ -922,10 +914,11 @@ if (type == chn_info::amino_acid && resi_vector[tmp1[0]].symbol1 == 'W')
 	iter_bl itb2 = find(mdl->GetBondsBegin(), mdl->GetBondsEnd(), b2);
 	bool b2exists = (itb2 != mdl->GetBondsEnd());
 	
-	if (b1exists == b2exists) { cout << "callEXIT : TRP-fix error #1" << endl; exit(EXIT_FAILURE); }
+	if (b1exists == b2exists) assertion_failed(__FILE__, __LINE__, "b1exists == b2exists");
+	
 	if (b1exists && !b2exists)
 	{
-		cout << "TRP-fix!!!" << endl;
+		cout << _("TRP-fix!!!") << endl;
 		
 		// ok, this seems to be "wrong" way...
 		// fix by exhanging 25<->29 and 26<->28.
@@ -955,8 +948,7 @@ if (type == chn_info::amino_acid && resi_vector[tmp1[0]].symbol1 == 'W')
 			
 			if (tmpseq1.size() != tmpseq3.size())
 			{
-				cout << "callEXIT : the seq1/seq3 arrays are bad!" << endl;
-				exit(EXIT_FAILURE);
+				assertion_failed(__FILE__, __LINE__, "tmpseq1.size() != tmpseq3.size()");
 			}
 			
 			chn_info newinfo(type, tmpseq1.size());
@@ -977,8 +969,8 @@ if (type == chn_info::amino_acid && resi_vector[tmp1[0]].symbol1 == 'W')
 			// and make some output...
 			
 			ostringstream str;
-			str << "chain " << newinfo.id_chn;
-			str << ", length " << newinfo.length << ":" << endl;
+			str << _("chain ") << newinfo.id_chn;
+			str << _(", length ") << newinfo.length << ":" << endl;
 			
 			for (i32u n3 = 0;n3 < tmpseq1.size();n3++)
 			{
@@ -1020,7 +1012,7 @@ if (type == chn_info::amino_acid && resi_vector[tmp1[0]].symbol1 == 'W')
 			
 			if ((* it1).GetConnRecCount() != 1)
 			{
-				cout << "WARNING : seqbuild : H atom with abnormal connectivity found." << endl;
+				cout << _("WARNING : seqbuild : H atom with abnormal connectivity found.") << endl;
 				continue;
 			}
 			
@@ -1110,8 +1102,7 @@ void sequencebuilder::Convert(sb_chain_descriptor * chde, sb_data_atm * adata, f
 		
 		if (n2 >= id_vector.size())
 		{
-			cout << "callEXIT : prev not found!" << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "prev not found!");
 		}
 		
 		prev[n1] = atom_vector[n2];
@@ -1119,7 +1110,9 @@ void sequencebuilder::Convert(sb_chain_descriptor * chde, sb_data_atm * adata, f
 	}
 	
 	const int tor_i = adata->ic2;
-//	int tor_i = adata->ic2;			// for debug only...
+///////////////////////////////////////////////////////////
+//	int tor_i = adata->ic2;		// for debug only...
+///////////////////////////////////////////////////////////
 	
 	bool store = false;
 	i32s p0i = NOT_DEFINED;
@@ -1130,18 +1123,20 @@ void sequencebuilder::Convert(sb_chain_descriptor * chde, sb_data_atm * adata, f
 	{
 		if (tor_i >= td_v.size())
 		{
-			cout << "callEXIT : td_v is incomplete ; " << tor_i << endl;
-			exit(EXIT_FAILURE);
+			ostringstream msg;
+			msg << "td_v is incomplete ; " << tor_i << ends;
+			assertion_failed(__FILE__, __LINE__, msg.str().c_str());
 		}
 		
 		if (!td_v[tor_i].flag)
 		{
 			if (adata->id != td_v[tor_i].id[0])
 			{
-				cout << "callEXIT : id mismatch ; ";
-				cout << hex << adata->id << " != ";
-				cout << hex << td_v[tor_i].id[0] << endl;
-				exit(EXIT_FAILURE);
+				ostringstream msg;
+				msg << "id mismatch ; ";
+				msg << hex << adata->id << " != ";
+				msg << hex << td_v[tor_i].id[0] << ends;
+				assertion_failed(__FILE__, __LINE__, msg.str().c_str());
 			}
 			
 			td_v[tor_i].flag = true;
@@ -1149,8 +1144,7 @@ void sequencebuilder::Convert(sb_chain_descriptor * chde, sb_data_atm * adata, f
 			
 			if (fabs(ic[2]) > 0.0001)
 			{
-				cout << "callEXIT : tor error" << endl;
-				exit(EXIT_FAILURE);
+				assertion_failed(__FILE__, __LINE__, "tor error");
 			}
 		}
 		
@@ -1176,18 +1170,16 @@ void sequencebuilder::Convert(sb_chain_descriptor * chde, sb_data_atm * adata, f
 		
 		if (p0i >= (i32s) id_vector.size())
 		{
-			cout << "callEXIT : p0i not found" << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "p0i not found");
 		}
 		else if (atom_vector[p0i] != prev[0])
 		{
-			cout << "callEXIT : p0i mismatch ; ";
-			cout << "0x" << hex << id_vector[p0i] << " " << prev[0] << endl;
-			
-		cout << "tordef " << hex << td_v[tor_i].id[0] << " " << hex << td_v[tor_i].id[1] << " ";
-		cout << hex << td_v[tor_i].id[2] << " " << hex << td_v[tor_i].id[3] << endl;
-			
-			exit(EXIT_FAILURE);
+			ostringstream msg;
+			msg << "p0i mismatch ; ";
+			msg << "0x" << hex << id_vector[p0i] << " " << prev[0] << endl;
+			msg << "tordef " << hex << td_v[tor_i].id[0] << " " << hex << td_v[tor_i].id[1] << " ";
+			msg << hex << td_v[tor_i].id[2] << " " << hex << td_v[tor_i].id[3] << ends;
+			assertion_failed(__FILE__, __LINE__, msg.str().c_str());
 		}
 		
 		// check prev1
@@ -1200,18 +1192,16 @@ void sequencebuilder::Convert(sb_chain_descriptor * chde, sb_data_atm * adata, f
 		
 		if (p1i >= (i32s) id_vector.size())
 		{
-			cout << "callEXIT : p1i not found" << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "p1i not found");
 		}
 		else if (atom_vector[p1i] != prev[1])
 		{
-			cout << "callEXIT : p1i mismatch ; ";
-			cout << "0x" << hex << id_vector[p1i] << " " << prev[1] << endl;
-			
-		cout << "tordef " << hex << td_v[tor_i].id[0] << " " << hex << td_v[tor_i].id[1] << " ";
-		cout << hex << td_v[tor_i].id[2] << " " << hex << td_v[tor_i].id[3] << endl;
-			
-			exit(EXIT_FAILURE);
+			ostringstream msg;
+			msg << "p1i mismatch ; ";
+			msg << "0x" << hex << id_vector[p1i] << " " << prev[1] << endl;
+			msg << "tordef " << hex << td_v[tor_i].id[0] << " " << hex << td_v[tor_i].id[1] << " ";
+			msg << hex << td_v[tor_i].id[2] << " " << hex << td_v[tor_i].id[3] << ends;
+			assertion_failed(__FILE__, __LINE__, msg.str().c_str());
 		}
 		
 		// check prev2
@@ -1224,18 +1214,16 @@ void sequencebuilder::Convert(sb_chain_descriptor * chde, sb_data_atm * adata, f
 		
 		if (p2i >= (i32s) id_vector.size())
 		{
-			cout << "callEXIT : p2i not found" << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "p2i not found");
 		}
 		else if (atom_vector[p2i] != prev[2])
 		{
-			cout << "callEXIT : p2i mismatch ; ";
-			cout << "0x" << hex << id_vector[p2i] << " " << prev[2] << endl;
-			
-		cout << "tordef " << hex << td_v[tor_i].id[0] << " " << hex << td_v[tor_i].id[1] << " ";
-		cout << hex << td_v[tor_i].id[2] << " " << hex << td_v[tor_i].id[3] << endl;
-			
-			exit(EXIT_FAILURE);
+			ostringstream msg;
+			msg << "p2i mismatch ; ";
+			msg << "0x" << hex << id_vector[p2i] << " " << prev[2] << endl;
+			msg << "tordef " << hex << td_v[tor_i].id[0] << " " << hex << td_v[tor_i].id[1] << " ";
+			msg << hex << td_v[tor_i].id[2] << " " << hex << td_v[tor_i].id[3] << ends;
+			assertion_failed(__FILE__, __LINE__, msg.str().c_str());
 		}
 	}
 	else
@@ -1274,7 +1262,7 @@ void sequencebuilder::Convert(sb_chain_descriptor * chde, sb_data_atm * adata, f
 			
 			if (all_match)
 			{
-				cout << "callEXIT : all_match ; tor_i = " << tor_i << endl;
+				cout << "DEBUG : all_match ; tor_i = " << tor_i << endl;
 				exit(EXIT_FAILURE);
 			}
 		}
@@ -1309,8 +1297,7 @@ void sequencebuilder::Convert(sb_chain_descriptor * chde, sb_data_atm * adata, f
 			
 			if (tor_i >= chde->def_tor.size())
 			{
-				cout << "callEXIT : cannot store a torsion." << endl;
-				exit(EXIT_FAILURE);
+				assertion_failed(__FILE__, __LINE__, "cannot store a torsion.");
 			}
 			else
 			{
@@ -1664,9 +1651,9 @@ istream & operator>>(istream & p1, sb_data_atm & p2)
 	p1 >> buffer;
 	p2.bt = bondtype(buffer[0]);
 	
-///////////////////////////////////////////////////////////////////////////////////////////////
-if (p2.bt.GetValue() == 0) { cout << "callEXIT : bad bondtype A" << endl; exit(EXIT_FAILURE); }
-///////////////////////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////
+if (p2.bt.GetValue() == 0) assertion_failed(__FILE__, __LINE__, "bad bondtype A");
+//////////////////////////////////////////////////////////////////////////
 	
 	return p1;
 }
@@ -1692,9 +1679,9 @@ istream & operator>>(istream & p1, sb_data_bnd & p2)
 	p1 >> p2.atm[0] >> p2.atm[1];
 	p1 >> buffer; p2.bt = bondtype(buffer[0]);
 	
-///////////////////////////////////////////////////////////////////////////////////////////////
-if (p2.bt.GetValue() == 0) { cout << "callEXIT : bad bondtype B" << endl; exit(EXIT_FAILURE); }
-///////////////////////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////
+if (p2.bt.GetValue() == 0) assertion_failed(__FILE__, __LINE__, "bad bondtype B");
+//////////////////////////////////////////////////////////////////////////
 	
 	return p1;
 }
@@ -1740,8 +1727,7 @@ void sb_data_res::ReadModification(istream & p1)
 	{
 		if (p1.peek() == 'T')
 		{
-			cout << "callEXIT : xxxx_MOD should not have any TORDEF lines!" << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "xxxx_MOD should not have TORDEF lines!");
 		}
 		
 		if (p1.peek() == 'A')
@@ -1779,8 +1765,9 @@ istream & operator>>(istream & p1, sb_data_res & p2)
 	p1 >> buffer;
 	if (strlen(buffer) != 3)
 	{
-		cout << "callEXIT : bad symbol3 : " << buffer << endl;
-		exit(EXIT_FAILURE);
+		ostringstream msg;
+		msg << "bad symbol3 : " << buffer << ends;
+		assertion_failed(__FILE__, __LINE__, msg.str().c_str());
 	}
 	
 	strcpy(p2.symbol3, buffer);
